@@ -116,19 +116,17 @@ class Formatter:
                 fixed_value = Formatter.snake_to_upper_camel_case(self.__tokens[pos].get_value())
                 self.__namings_to_fix[self.__tokens[pos].get_primary_value()] = fixed_value
             pos = self.__fix_generic_if_exists(pos)
-        self.__fix_class_params(pos)
+            self.__fix_class_params(pos)
         return pos
 
     def __fix_generic_if_exists(self, pos):
         pos = self.__skip_ws_tokens(pos + 1)
         if self.__tokens[pos].get_value() == '[':
-            pos = self.__skip_ws_tokens(pos + 1)
             if Formatter.__is_not_upper_camel_case(self.__tokens[pos].get_value()):
                 self.__namings_to_fix[self.__tokens[pos].get_value()] = Formatter.snake_to_upper_camel_case(
                     self.__tokens[pos].get_value())
             while self.__tokens[pos].get_value() != ']':
                 pos += 1
-        pos += 1
         return pos
 
     def __fix_comments(self):
@@ -262,7 +260,9 @@ class Formatter:
             return
         ws = ''
         i = pos - 1
-        while self.__tokens[i].get_value() != '\n' and i > 0:
+        if i < 0:
+            i = 0
+        while self.__tokens[i].get_value() != '\n' and i >= 0:
             i -= 1
         pos = i
         i += 1
@@ -271,7 +271,7 @@ class Formatter:
             i += 1
         pos = i
         params = self.__find_trait_params(pos)
-        comment = '\n' + ws + '/** '
+        comment = ('\n' if pos != 0 else '') + ws + '/** '
         for i in params:
             comment += f'{Formatter.snake_to_lower_camel_case(i) if Formatter.__is_not_lower_camel_case(i) else i} must be specified in class using this\n'
         comment += ws + '*/\n' + ws
@@ -329,6 +329,8 @@ class Formatter:
         else:
             ws = ''
             i = pos - 1
+            if i < 0:
+                i = 0
             while self.__tokens[i].get_value() != '\n' and i > 0:
                 i -= 1
             pos = i
@@ -346,8 +348,9 @@ class Formatter:
                       for throw in throws]
             extends = [self.snake_to_upper_camel_case(value) if Formatter.__is_not_upper_camel_case(value) else value
                        for value in extends]
+            name = Formatter.snake_to_upper_camel_case(name) if Formatter.__is_not_upper_camel_case(name) else name
 
-            comment = '\n' + ws + '/** '
+            comment = ('\n' if pos != 0 else '') + ws + '/** '
             comment += f"@constructor Create a new {name}{' with specified ' if len(params) > 0 else ''}{', '.join(params)}\n"
             for i in type_params:
                 comment += ws + f'  * @tparam {i}\n'
@@ -357,9 +360,10 @@ class Formatter:
                 comment += ws + f'  * @throws {i}\n'
             for i in extends:
                 comment += ws + f'  * @extends {i}\n'
-            comment += ws + '*/'
+            comment += ws + '*/\n'
             token = Token(None, TokenType.COMMENT, self.__tokens[pos].get_position())
             token.set_fixed_value(comment)
+            print(pos)
             self.__tokens.insert(pos, token)
 
     @staticmethod
@@ -418,7 +422,7 @@ class Formatter:
         i = 0
         while i < len(self.__tokens):
             if self.__tokens[i].get_value() == 'def':
-                self.__fix_method_params(i+1)
+                self.__fix_method_params(i + 1)
             i += 1
 
     def __fix_method_params(self, pos):
@@ -443,7 +447,8 @@ class Formatter:
                     pos = self.__skip_ws_tokens(pos + 1)
                     if Formatter.__is_not_lower_camel_case(self.__tokens[pos].get_value()):
                         params.append(self.__tokens[pos].get_value())
-                        self.__tokens[pos].set_fixed_value(Formatter.snake_to_lower_camel_case(self.__tokens[pos].get_value()))
+                        self.__tokens[pos].set_fixed_value(
+                            Formatter.snake_to_lower_camel_case(self.__tokens[pos].get_value()))
                     elif current == 'val':
                         self.__tokens[pos].set_fixed_value(self.__tokens[pos].get_value())
                 pos += 1
@@ -453,7 +458,8 @@ class Formatter:
         brace_found = False
         brace_count = 0
         while not (brace_found and brace_count == 0):
-            if self.__tokens[pos].get_value() in params and Formatter.__is_not_lower_camel_case(self.__tokens[pos].get_value()):
+            if self.__tokens[pos].get_value() in params and Formatter.__is_not_lower_camel_case(
+                    self.__tokens[pos].get_value()):
                 self.__tokens[pos].set_fixed_value(
                     Formatter.snake_to_lower_camel_case(self.__tokens[pos].get_value()))
             elif self.__tokens[pos].get_value() == '{':
@@ -568,7 +574,7 @@ class Formatter:
         params = []
         brace_found = False
         colon_found = False
-        while self.__tokens[pos].get_value() not in ('{', '='):
+        while self.__tokens[pos].get_value() not in ('{', '=') and pos < len(self.__tokens):
             token = self.__tokens[pos]
             if token.get_value() == '(':
                 brace_found = True
@@ -615,7 +621,7 @@ class Formatter:
             comment.set_fixed_value(
                 Formatter.__add_to_comment_if_not_exists('@extends', extends, comment.get_value(), True))
         else:
-            comment = '\n' + '/** '
+            comment = ('\n' if pos != 0 else '') + '/** '
             for i in extends:
                 comment += f'@extends {i}\n'
             comment += '*/\n'
@@ -740,8 +746,16 @@ class Formatter:
             return i
 
     def __fix_namings(self, namings_to_fix):
-        for token in self.__tokens:
+        i = 0
+        while i < len(self.__tokens):
+            token = self.__tokens[i]
             if token.get_value() in namings_to_fix.keys():
-                token.set_fixed_value(namings_to_fix[token.get_value()])
+                prev = i - 1
+                while self.__tokens[prev].get_token_type() == TokenType.WHITESPACE:
+                    prev -= 1
+                _next = self.__skip_ws_tokens(i + 1)
+                if self.__tokens[prev] not in ('def', 'val', 'var') and self.__tokens[_next] != ':':
+                    token.set_fixed_value(namings_to_fix[token.get_value()])
             elif token.get_token_type() == TokenType.ANNOTATION and token.get_value()[1:] in namings_to_fix.keys():
                 token.set_fixed_value('@' + namings_to_fix[token.get_value()[1:]])
+            i += 1
